@@ -1,38 +1,41 @@
-from typing import Coroutine, Any
-from nonebot import on_command, on_regex
+from typing import Coroutine, Any, List
+from nonebot import on_command, on_regex, logger, require
 from nonebot.typing import T_State
 from nonebot.permission import SUPERUSER
-from nonebot.adapters.onebot.v11 import GROUP, GROUP_ADMIN, GROUP_OWNER, Message, MessageEvent, GroupMessageEvent
+from nonebot.adapters.onebot.v11 import Bot, GROUP, GROUP_ADMIN, GROUP_OWNER, Message, MessageEvent, MessageSegment, GroupMessageEvent
 from nonebot.params import Depends, Arg, ArgStr, CommandArg, RegexMatched
 from nonebot.matcher import Matcher
-from nonebot import logger
-from nonebot_plugin_apscheduler import scheduler
-from .config import Meals
+from .utils import Meals, save_cq_image
 from .data_source import eating_manager
 
-__what2eat_version__ = "v0.3.1"
+require("nonebot_plugin_apscheduler")
+from nonebot_plugin_apscheduler import scheduler
+
+__what2eat_version__ = "v0.3.4"
 __what2eat_notes__ = f'''
 今天吃什么？ {__what2eat_version__}
-[xx吃xx]    问bot恰什么
+[xx吃xx]    问bot吃什么
+[xx喝xx]    问bot喝什么
 [添加 xx]   添加菜品至群菜单
 [移除 xx]   从菜单移除菜品
 [加菜 xx]   添加菜品至基础菜单
-[菜单]       查看群菜单
-[基础菜单]  查看基础菜单
+[菜单]        查看群菜单
+[基础菜单] 查看基础菜单
 [开启/关闭小助手] 开启/关闭吃饭小助手
 [添加/删除问候 时段 问候语] 添加/删除吃饭小助手问候语'''.strip()
 
 what2eat = on_regex(r"^(今天|[早中午晚][上饭餐午]|早上|夜宵|今晚)吃(什么|啥|点啥)(帮助)?$", priority=15)
+what2drink = on_regex(r"^(今天|[早中午晚][上饭餐午]|早上|夜宵|今晚)喝(什么|啥|点啥)(帮助)?$", priority=15)
 group_add = on_command("添加", permission=SUPERUSER | GROUP_ADMIN | GROUP_OWNER, priority=15, block=True)
 group_remove = on_command("移除", permission=SUPERUSER | GROUP_ADMIN | GROUP_OWNER, priority=15, block=True)
 basic_add = on_command("加菜", permission=SUPERUSER, priority=15, block=True)
 show_group_menu = on_command("菜单", aliases={"群菜单", "查看菜单"}, permission=GROUP, priority=15, block=True)
 show_basic_menu = on_command("基础菜单", permission=GROUP, priority=15, block=True)
 
-greeting_on = on_command("开启小助手", aliases={"启用小助手"}, permission=SUPERUSER | GROUP_ADMIN | GROUP_OWNER, priority=15, block=True)
-greeting_off = on_command("关闭小助手", aliases={"禁用小助手"}, permission=SUPERUSER | GROUP_ADMIN | GROUP_OWNER, priority=15, block=True)
-add_greeting = on_command("添加问候", aliases={"添加问候语"}, permission=SUPERUSER | GROUP_ADMIN | GROUP_OWNER, priority=15, block=True)
-remove_greeting = on_command("删除问候", aliases={"删除问候语", "移除问候", "移除问候语"}, permission=SUPERUSER | GROUP_ADMIN | GROUP_OWNER, priority=15, block=True)
+greeting_on = on_command("开启小助手", aliases={"启用小助手"}, permission=SUPERUSER | GROUP_ADMIN | GROUP_OWNER, priority=12, block=True)
+greeting_off = on_command("关闭小助手", aliases={"禁用小助手"}, permission=SUPERUSER | GROUP_ADMIN | GROUP_OWNER, priority=12, block=True)
+add_greeting = on_command("添加问候", aliases={"添加问候语"}, permission=SUPERUSER | GROUP_ADMIN | GROUP_OWNER, priority=12, block=True)
+remove_greeting = on_command("删除问候", aliases={"删除问候语", "移除问候", "移除问候语"}, permission=SUPERUSER | GROUP_ADMIN | GROUP_OWNER, priority=12, block=True)
 
 @what2eat.handle()
 async def _(event: MessageEvent, args: str = RegexMatched()):
@@ -41,59 +44,79 @@ async def _(event: MessageEvent, args: str = RegexMatched()):
     
     msg = eating_manager.get2eat(event)
     await what2eat.finish(msg)
+    
+@what2drink.handle()
+async def _(event: MessageEvent, args: str = RegexMatched()):
+    if args[-2:] == "帮助":
+        await what2drink.finish(__what2eat_notes__)
+    
+    msg = eating_manager.get2drink(event)
+    await what2drink.finish(msg)
 
 @group_add.handle()
 async def _(event: GroupMessageEvent, args: Message = CommandArg()):
-    args = args.extract_plain_text().strip().split()
-    if not args:
+    args_str: List[str] = args.extract_plain_text().strip().split()
+    if not args_str:
         await group_add.finish("还没输入你要添加的菜品呢~")
-    elif args and len(args) == 1:
-        new_food = args[0]
-    else:
+    elif len(args_str) > 1:
         await group_add.finish("添加菜品参数错误~")
     
-    msg = eating_manager.add_group_food(new_food, event)
-
-    await group_add.finish(msg)
+    # If image included, save it, return the path in string
+    await save_cq_image(args, eating_manager._img_dir)
+    
+    # Record the whole string, including the args after transfering
+    msg: str = eating_manager.add_group_food(event, str(args))
+    
+    if "[CQ:image" in str(args):
+        await group_add.finish(args.append(MessageSegment.text(" " + msg)))
+    else:
+        await group_add.finish(args.append(MessageSegment.text(msg)))
 
 @basic_add.handle()
 async def _(args: Message = CommandArg()):
-    args = args.extract_plain_text().strip().split()
-    if not args:
+    args_str: List[str] = args.extract_plain_text().strip().split()
+    if not args_str:
         await basic_add.finish("还没输入你要添加的菜品呢~")
-    elif args and len(args) == 1:
-        new_food = args[0]
+    elif len(args_str) > 1:
+        await group_add.finish("添加菜品参数错误~")
+
+    # The same as above
+    await save_cq_image(args, eating_manager._img_dir)
+    msg: str = eating_manager.add_basic_food(str(args))
+
+    if "[CQ:image" in str(args):
+        await group_add.finish(args.append(MessageSegment.text(" " + msg)))
     else:
-        await basic_add.finish("添加菜品参数错误~")
-
-    msg = eating_manager.add_basic_food(new_food)
-
-    await basic_add.finish(msg)
+        await group_add.finish(args.append(MessageSegment.text(msg)))
 
 @group_remove.handle()
 async def _(event: GroupMessageEvent, args: Message = CommandArg()):
-    args = args.extract_plain_text().strip().split()
+    args: List[str] = args.extract_plain_text().strip().split()
     if not args:
         await group_remove.finish("还没输入你要移除的菜品呢~")
-    elif args and len(args) == 1:
-        food_to_remove = args[0]
-    else:
+    elif len(args) > 1:
         await group_remove.finish("移除菜品参数错误~")
 
-    msg = eating_manager.remove_food(event, food_to_remove)
+    msg: MessageSegment = eating_manager.remove_food(event, args[0])
 
-    await group_remove.finish(msg)
+    await group_remove.finish(MessageSegment.text(msg))
 
 @show_group_menu.handle()
-async def _(event: GroupMessageEvent):
+async def _(bot: Bot, matcher: Matcher, event: GroupMessageEvent):
     gid = str(event.group_id)
-    msg = eating_manager.show_group_menu(gid)
-    await show_group_menu.finish(msg)
+    is_too_many_lines, msg = eating_manager.show_group_menu(gid)
+    if is_too_many_lines:
+        await bot.call_api("send_group_forward_msg", group_id=event.group_id, messages=MessageSegment.node_custom(int(bot.self_id), list(bot.config.nickname)[0], msg))
+    else:
+        await matcher.finish(msg)
 
 @show_basic_menu.handle()
-async def _(matcher: Matcher):
-    msg = eating_manager.show_basic_menu()
-    await matcher.finish(msg)
+async def _(bot: Bot, matcher: Matcher, event: GroupMessageEvent):
+    is_too_many_lines, msg = eating_manager.show_basic_menu()
+    if is_too_many_lines:
+        await bot.call_api("send_group_forward_msg", group_id=event.group_id, messages=MessageSegment.node_custom(int(bot.self_id), list(bot.config.nickname)[0], msg))
+    else:
+        await matcher.finish(msg)
 
 # ------------------------- Greetings -------------------------
 @greeting_on.handle()
